@@ -3,7 +3,7 @@ import os.path
 import yaml
 from sdcclient import SdSecureClient, SdScanningClient, SdSecureClientV1
 from sdcclient import SdMonitorClient as SdMonitorClientV2
-from sdccli.client_v3.monitor import SdMonitorClient
+from sdcclient import SdMonitorClient
 
 from sdccli.cli.formatter.json_formatter import JsonFormatter
 from sdccli.cli.formatter.text_formatter import NormalFormatter
